<?php
namespace Pinpoint\DeliveryDate\Controller\Adminhtml\Estimated;

use Magento\Backend\App\Action;

/**
 * Class Delete
 * @package Pinpoint\DeliveryDate\Controller\Adminhtml\Estimated
 */
class Delete extends \Magento\Backend\App\Action
{
    /**
     * @var string
     */
    const ADMIN_RESOURCE = 'Pinpoint_DeliveryDate::delivery_dates';

    /**
     * @var \Pinpoint\DeliveryDate\Model\EstimatedDateRepository
     */
    protected $estimatedDate;

    /**
     * Delete constructor.
     * @param Action\Context $context
     * @param \Pinpoint\DeliveryDate\Model\EstimatedDateRepository $estimatedDate
     */
    public function __construct(
        Action\Context $context,
        \Pinpoint\DeliveryDate\Model\EstimatedDateRepository $estimatedDate
    ) {
        $this->estimatedDate = $estimatedDate;
        parent::__construct($context);
    }

    /**
     * Check the permission to run it
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_DeliveryDate::delivery_dates');
    }

    /**
     * @return \Magento\Backend\Model\View\Result\Redirect
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                $this->estimatedDate->deleteById($id);

                $this->messageManager->addSuccess(__('You have deleted the estimation.'));
                return $resultRedirect->setPath('*/*/list');
            } catch (\Exception $e) {
                $this->messageManager->addError($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', ['id' => $id]);
            }
        }

        $this->messageManager->addError(__('We can not find an estimation to delete.'));
        return $resultRedirect->setPath('*/*/list');
    }
}
